"use strict";

// istanbul ignore next

var _interopRequire = function (obj) { return obj && obj.__esModule ? obj["default"] : obj; };

// istanbul ignore next

var _toConsumableArray = function (arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) arr2[i] = arr[i]; return arr2; } else { return Array.from(arr); } };

var postcss = _interopRequire(require("postcss"));

var list = _interopRequire(require("postcss/lib/list"));

module.exports = function () {
  return function (css) {
    css.eachAtRule(processAtRule);
  };
};

function processAtRule(atRule) {
  if (!reAtRule.test(atRule.name)) {
    return;
  }var args = list.space(atRule.params);
  var parent = atRule.parent;
  var root = parent.root();
  var selectors = quantifiers[atRule.name].apply(quantifiers, _toConsumableArray(args))(parent.selectors);

  var newRule = postcss.rule({
    selectors: selectors,
    nodes: atRule.nodes,
    source: atRule.source,
    semicolon: true
  });

  cleanIndent(newRule);

  root.insertAfter(parent, newRule);
  atRule.removeSelf();

  if (!parent.nodes.length) parent.removeSelf();
}

var reAtRule = /(:?at-(:?least|most)|between|exactly)/;

var cleanIndent = function (rule) {
  return rule.eachDecl(function (decl) {
    decl.before = decl.before.replace(/[^\S\x0a\x0d]{2,}/, "  ");
  });
};

var quantitySelectors = function (quantifier, last) {
  return function (selectors) {
    return selectors.map(function (s) {
      return "" + s + "" + quantifier + ", " + s + "" + quantifier + " ~ " + (last || list.space(s).pop());
    });
  };
};

var quantifiers = {

  "at-least": function (count, last) {
    return quantitySelectors(":nth-last-child(n+" + count + ")", last);
  },

  "at-most": function (count, last) {
    return quantitySelectors(":nth-last-child(-n+" + count + "):first-child", last);
  },

  between: function (start, end, last) {
    return quantitySelectors(":nth-last-child(n+" + start + "):nth-last-child(-n+" + end + "):first-child", last);
  },

  exactly: function (count, last) {
    return quantitySelectors(":nth-last-child(" + count + "):first-child", last);
  }

};